Learn R Programming

amerifluxr (version 1.0.0)

amf_variables: Get FP (Flux-Processing) Standard Variable List

Description

This function obtains the latest AmeriFlux FP (Flux-Processing) standard variable list. FP standard defines the variable names and units used for continuously sampled data within the AmeriFlux. Also see AmeriFlux Data Variables page https://ameriflux.lbl.gov/data/aboutdata/data-variables/ for details.

Usage

amf_variables()

Arguments

Value

A data frame containing the following columns:

  • Name - Standard variable name

  • Description - Description of the variable

  • Units - Standard variable unit

  • Min - Expected minimal value

  • Max - Expected maximal value

Examples

Run this code
# NOT RUN {
# download the list of standard variable names and units
FP_ls <- amf_variables()
# }

Run the code above in your browser using DataLab